@@ -12,8 +12,8 @@ TIMEOUT = 1.0
 
 def test_threadpool():
     net = findssh.netfromaddress(findssh.getLANip())
-    host_res = findssh.threadpool.get_hosts(net, PORT, SERVICE, TIMEOUT)
-    for host, svc in host_res:
+    hosts = findssh.threadpool.get_hosts(net, PORT, SERVICE, TIMEOUT)
+    for host, svc in hosts:
         assert isinstance(host, ipaddress.IPv4Address)
         assert isinstance(svc, str)
         break
